@@ -464,18 +464,27 @@ class BaseAdaptEstimator(BaseAdapt, BaseEstimator):
         """
         Xt, yt = self._get_target_data(Xt, yt)
         X, y = check_arrays(X, y)
+        self.n_features_in_ = X.shape[1]
         if yt is not None:
             Xt, yt = check_arrays(Xt, yt)
         else:
             Xt = check_array(Xt, ensure_2d=True, allow_nd=True)
         set_random_seed(self.random_state)
+        
+        self.n_features_in_ = X.shape[1]
  
         if hasattr(self, "fit_weights"):
             if self.verbose:
                 print("Fit weights...")
-            self.weights_ = self.fit_weights(Xs=X, Xt=Xt,
-                                             ys=y, yt=yt,
-                                             domains=domains)
+            out = self.fit_weights(Xs=X, Xt=Xt,
+                                   ys=y, yt=yt,
+                                   domains=domains)
+            if isinstance(out, tuple):
+                self.weights_ = out[0]
+                X = out[1]
+                y = out[2]
+            else:
+                self.weights_ = out
             if "sample_weight" in fit_params:
                 fit_params["sample_weight"] *= self.weights_
             else:
@@ -1348,7 +1357,8 @@ class BaseAdaptDeep(Model, BaseAdapt):
             loss = tf.reduce_mean(loss)
 
         # Run backwards pass.
-        self.optimizer.minimize(loss, self.trainable_variables, tape=tape)
+        gradients = tape.gradient(loss, self.trainable_variables)
+        self.optimizer.apply_gradients(zip(gradients, self.trainable_variables))
         self.compiled_metrics.update_state(ys, y_pred)
         # Collect metrics to return
         return_metrics = {}
@@ -1644,23 +1654,23 @@ class BaseAdaptDeep(Model, BaseAdapt):
     
     def _initialize_networks(self):
         if self.encoder is None:
-            self.encoder_ = get_default_encoder(name="encoder")
+            self.encoder_ = get_default_encoder(name="encoder", state=self.random_state)
         else:
             self.encoder_ = check_network(self.encoder,
                                           copy=self.copy,
                                           name="encoder")
         if self.task is None:
-            self.task_ = get_default_task(name="task")
+            self.task_ = get_default_task(name="task", state=self.random_state)
         else:
             self.task_ = check_network(self.task,
                                        copy=self.copy,
                                        name="task")
         if self.discriminator is None:
-            self.discriminator_ = get_default_discriminator(name="discriminator")
+            self.discriminator_ = get_default_discriminator(name="discriminator", state=self.random_state)
         else:
             self.discriminator_ = check_network(self.discriminator,
                                                 copy=self.copy,
                                                 name="discriminator")
             
     def _initialize_pretain_networks(self):
-        pass
\ No newline at end of file
+        pass
