@@ -14,6 +14,8 @@ from ._cdan import CDAN
 from ._sa import SA
 from ._fmmd import fMMD
 from ._ccsa import CCSA
+from ._tca import TCA
+from ._pred import PRED
 
 __all__ = ["FA", "CORAL", "DeepCORAL", "ADDA", "DANN",
-           "MCD", "MDD", "WDGRL", "CDAN", "SA", "fMMD", "CCSA"]
+           "MCD", "MDD", "WDGRL", "CDAN", "SA", "fMMD", "CCSA", "TCA", "PRED"]
