@@ -6,7 +6,7 @@ import numpy as np
 import tensorflow as tf
 
 from adapt.base import BaseAdaptDeep, make_insert_doc
-
+from tensorflow.keras.initializers import GlorotUniform
 from adapt.utils import (check_network,
                          get_default_encoder,
                          get_default_discriminator)
@@ -14,20 +14,29 @@ from adapt.utils import (check_network,
 EPS = np.finfo(np.float32).eps
 
 
-def _get_default_classifier(name=None):
+def _get_default_classifier(name=None, state=None):
     model = tf.keras.Sequential(name=name)
     model.add(tf.keras.layers.Flatten())
-    model.add(tf.keras.layers.Dense(10, activation="relu"))
-    model.add(tf.keras.layers.Dense(10, activation="relu"))
-    model.add(tf.keras.layers.Dense(2, activation="softmax"))
+    if state is None:
+        model.add(tf.keras.layers.Dense(10, activation="relu"))
+        model.add(tf.keras.layers.Dense(10, activation="relu"))
+        model.add(tf.keras.layers.Dense(2, activation="softmax"))
+    else:
+        model.add(tf.keras.layers.Dense(10, activation="relu",
+                                       kernel_initializer=GlorotUniform(seed=state)))
+        model.add(tf.keras.layers.Dense(10, activation="relu",
+                                       kernel_initializer=GlorotUniform(seed=state)))
+        model.add(tf.keras.layers.Dense(2, activation="softmax",
+                                       kernel_initializer=GlorotUniform(seed=state)))
     return model
 
 
 @make_insert_doc(["encoder"])
 class CDAN(BaseAdaptDeep):
     """
-    CDAN (Conditional Adversarial Domain Adaptation) is an
-    unsupervised domain adaptation method on the model of the 
+    CDAN: Conditional Adversarial Domain Adaptation
+    
+    CDAN is an unsupervised domain adaptation method on the model of the 
     :ref:`DANN <adapt.feature_based.DANN>`. In CDAN the discriminator
     is conditioned on the prediction of the task network for
     source and target data. This should , in theory, focus the
@@ -311,19 +320,19 @@ In NIPS, 2018
     
     def _initialize_networks(self):
         if self.encoder is None:
-            self.encoder_ = get_default_encoder(name="encoder")
+            self.encoder_ = get_default_encoder(name="encoder", state=self.random_state)
         else:
             self.encoder_ = check_network(self.encoder,
                                           copy=self.copy,
                                           name="encoder")
         if self.task is None:
-            self.task_ = _get_default_classifier(name="task")
+            self.task_ = _get_default_classifier(name="task", state=self.random_state)
         else:
             self.task_ = check_network(self.task,
                                        copy=self.copy,
                                        name="task")
         if self.discriminator is None:
-            self.discriminator_ = get_default_discriminator(name="discriminator")
+            self.discriminator_ = get_default_discriminator(name="discriminator", state=self.random_state)
         else:
             self.discriminator_ = check_network(self.discriminator,
                                                 copy=self.copy,
